==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TimeChaosSpecFluent<A extends TimeChaosSpecFluent<A>> extends BaseFluent<A>{
  public TimeChaosSpecFluent() {
  }
  public TimeChaosSpecFluent(TimeChaosSpec instance) {
    instance = (instance != null ? instance : new TimeChaosSpec());

    if (instance != null) {
      this.withClockIds(instance.getClockIds());
      this.withContainerNames(instance.getContainerNames());
      this.withDuration(instance.getDuration());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withTimeOffset(instance.getTimeOffset());
      this.withValue(instance.getValue());
      this.withClockIds(instance.getClockIds());
      this.withContainerNames(instance.getContainerNames());
      this.withDuration(instance.getDuration());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withTimeOffset(instance.getTimeOffset());
      this.withValue(instance.getValue());
    }
  }
  private List<String> clockIds = new ArrayList<String>();
  private List<String> containerNames = new ArrayList<String>();
  private String duration;
  private String mode;
  private PodSelectorSpecBuilder selector;
  private String timeOffset;
  private String value;
  public A addToClockIds(int index,String item) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    this.clockIds.add(index, item);
    return (A)this;
  }
  public A setToClockIds(int index,String item) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    this.clockIds.set(index, item); return (A)this;
  }
  public A addToClockIds(java.lang.String... items) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    for (String item : items) {this.clockIds.add(item);} return (A)this;
  }
  public A addAllToClockIds(Collection<String> items) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    for (String item : items) {this.clockIds.add(item);} return (A)this;
  }
  public A removeFromClockIds(java.lang.String... items) {
    if (this.clockIds == null) return (A)this;
    for (String item : items) { this.clockIds.remove(item);} return (A)this;
  }
  public A removeAllFromClockIds(Collection<String> items) {
    if (this.clockIds == null) return (A)this;
    for (String item : items) { this.clockIds.remove(item);} return (A)this;
  }
  public List<String> getClockIds() {
    return this.clockIds;
  }
  public String getClockId(int index) {
    return this.clockIds.get(index);
  }
  public String getFirstClockId() {
    return this.clockIds.get(0);
  }
  public String getLastClockId() {
    return this.clockIds.get(clockIds.size() - 1);
  }
  public String getMatchingClockId(Predicate<String> predicate) {
    for (String item: clockIds) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingClockId(Predicate<String> predicate) {
    for (String item: clockIds) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withClockIds(List<String> clockIds) {
    if (clockIds != null) {this.clockIds = new ArrayList(); for (String item : clockIds){this.addToClockIds(item);}} else { this.clockIds = null;} return (A) this;
  }
  public A withClockIds(java.lang.String... clockIds) {
    if (this.clockIds != null) {this.clockIds.clear(); _visitables.remove("clockIds"); }
    if (clockIds != null) {for (String item :clockIds){ this.addToClockIds(item);}} return (A) this;
  }
  public boolean hasClockIds() {
    return clockIds != null && !clockIds.isEmpty();
  }
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  public String getMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {this.containerNames = new ArrayList(); for (String item : containerNames){this.addToContainerNames(item);}} else { this.containerNames = null;} return (A) this;
  }
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {this.containerNames.clear(); _visitables.remove("containerNames"); }
    if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (A) this;
  }
  public boolean hasContainerNames() {
    return containerNames != null && !containerNames.isEmpty();
  }
  public String getDuration() {
    return this.duration;
  }
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  public boolean hasDuration() {
    return this.duration != null;
  }
  public String getMode() {
    return this.mode;
  }
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  public boolean hasMode() {
    return this.mode != null;
  }
  public PodSelectorSpec buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(PodSelectorSpec selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodSelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public boolean hasSelector() {
    return this.selector != null;
  }
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  public String getTimeOffset() {
    return this.timeOffset;
  }
  public A withTimeOffset(String timeOffset) {
    this.timeOffset=timeOffset; return (A) this;
  }
  public boolean hasTimeOffset() {
    return this.timeOffset != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimeChaosSpecFluent that = (TimeChaosSpecFluent) o;
    if (!java.util.Objects.equals(clockIds, that.clockIds)) return false;

    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;

    if (!java.util.Objects.equals(duration, that.duration)) return false;

    if (!java.util.Objects.equals(mode, that.mode)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    if (!java.util.Objects.equals(timeOffset, that.timeOffset)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clockIds,  containerNames,  duration,  mode,  selector,  timeOffset,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clockIds != null && !clockIds.isEmpty()) { sb.append("clockIds:"); sb.append(clockIds + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (timeOffset != null) { sb.append("timeOffset:"); sb.append(timeOffset + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    public N and() {
      return (N) TimeChaosSpecFluent.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TimeChaosSpecFluent<A extends TimeChaosSpecFluent<A>> extends BaseFluent<A>{
  public TimeChaosSpecFluent() {
  }
  
  public TimeChaosSpecFluent(TimeChaosSpec instance) {
    this.copyInstance(instance);
  }
  private List<String> clockIds = new ArrayList<String>();
  private List<String> containerNames = new ArrayList<String>();
  private String duration;
  private String mode;
  private PodSelectorSpecBuilder selector;
  private String timeOffset;
  private String value;
  
  protected void copyInstance(TimeChaosSpec instance) {
    instance = (instance != null ? instance : new TimeChaosSpec());
  
    if (instance != null) {
        this.withClockIds(instance.getClockIds());
        this.withContainerNames(instance.getContainerNames());
        this.withDuration(instance.getDuration());
        this.withMode(instance.getMode());
        this.withSelector(instance.getSelector());
        this.withTimeOffset(instance.getTimeOffset());
        this.withValue(instance.getValue());
        this.withClockIds(instance.getClockIds());
        this.withContainerNames(instance.getContainerNames());
        this.withDuration(instance.getDuration());
        this.withMode(instance.getMode());
        this.withSelector(instance.getSelector());
        this.withTimeOffset(instance.getTimeOffset());
        this.withValue(instance.getValue());
      }
  }
  
  public A addToClockIds(int index,String item) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    this.clockIds.add(index, item);
    return (A)this;
  }
  
  public A setToClockIds(int index,String item) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    this.clockIds.set(index, item); return (A)this;
  }
  
  public A addToClockIds(java.lang.String... items) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    for (String item : items) {this.clockIds.add(item);} return (A)this;
  }
  
  public A addAllToClockIds(Collection<String> items) {
    if (this.clockIds == null) {this.clockIds = new ArrayList<String>();}
    for (String item : items) {this.clockIds.add(item);} return (A)this;
  }
  
  public A removeFromClockIds(java.lang.String... items) {
    if (this.clockIds == null) return (A)this;
    for (String item : items) { this.clockIds.remove(item);} return (A)this;
  }
  
  public A removeAllFromClockIds(Collection<String> items) {
    if (this.clockIds == null) return (A)this;
    for (String item : items) { this.clockIds.remove(item);} return (A)this;
  }
  
  public List<String> getClockIds() {
    return this.clockIds;
  }
  
  public String getClockId(int index) {
    return this.clockIds.get(index);
  }
  
  public String getFirstClockId() {
    return this.clockIds.get(0);
  }
  
  public String getLastClockId() {
    return this.clockIds.get(clockIds.size() - 1);
  }
  
  public String getMatchingClockId(Predicate<String> predicate) {
    for (String item: clockIds) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingClockId(Predicate<String> predicate) {
    for (String item: clockIds) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withClockIds(List<String> clockIds) {
    if (clockIds != null) {this.clockIds = new ArrayList(); for (String item : clockIds){this.addToClockIds(item);}} else { this.clockIds = null;} return (A) this;
  }
  
  public A withClockIds(java.lang.String... clockIds) {
    if (this.clockIds != null) {this.clockIds.clear(); _visitables.remove("clockIds"); }
    if (clockIds != null) {for (String item :clockIds){ this.addToClockIds(item);}} return (A) this;
  }
  
  public boolean hasClockIds() {
    return clockIds != null && !clockIds.isEmpty();
  }
  
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  
  public String getMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {this.containerNames = new ArrayList(); for (String item : containerNames){this.addToContainerNames(item);}} else { this.containerNames = null;} return (A) this;
  }
  
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {this.containerNames.clear(); _visitables.remove("containerNames"); }
    if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (A) this;
  }
  
  public boolean hasContainerNames() {
    return containerNames != null && !containerNames.isEmpty();
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodSelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getTimeOffset() {
    return this.timeOffset;
  }
  
  public A withTimeOffset(String timeOffset) {
    this.timeOffset=timeOffset; return (A) this;
  }
  
  public boolean hasTimeOffset() {
    return this.timeOffset != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimeChaosSpecFluent that = (TimeChaosSpecFluent) o;
    if (!java.util.Objects.equals(clockIds, that.clockIds)) return false;
  
    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;
  
    if (!java.util.Objects.equals(duration, that.duration)) return false;
  
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    if (!java.util.Objects.equals(selector, that.selector)) return false;
  
    if (!java.util.Objects.equals(timeOffset, that.timeOffset)) return false;
  
    if (!java.util.Objects.equals(value, that.value)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clockIds,  containerNames,  duration,  mode,  selector,  timeOffset,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clockIds != null && !clockIds.isEmpty()) { sb.append("clockIds:"); sb.append(clockIds + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (timeOffset != null) { sb.append("timeOffset:"); sb.append(timeOffset + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) TimeChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}
